Events
======

.. py:currentmodule:: alsa_midi

.. autoclass:: Event
   :members:

.. autoclass:: EventType
   :members:
   :undoc-members:

.. autoclass:: EventFlags
   :members:
   :undoc-members:
.. autoclass:: NoteEvent
    :members:
    :inherited-members:

.. autoclass:: NoteOnEvent
    :members:
    :inherited-members:

.. autoclass:: NoteOffEvent
    :members:
    :inherited-members:

.. autoclass:: KeyPressureEvent
    :members:
    :inherited-members:

.. autoclass:: ControlChangeEvent
    :members:
    :inherited-members:

.. autoclass:: ProgramChangeEvent
    :members:
    :inherited-members:

.. autoclass:: ChannelPressureEvent
    :members:
    :inherited-members:

.. autoclass:: PitchBendEvent
    :members:
    :inherited-members:

.. autoclass:: Control14BitChangeEvent
    :members:
    :inherited-members:

.. autoclass:: NonRegisteredParameterChangeEvent
    :members:
    :inherited-members:

.. autoclass:: RegisteredParameterChangeEvent
    :members:
    :inherited-members:

.. autoclass:: SongPositionPointerEvent
    :members:
    :inherited-members:

.. autoclass:: SongSelectEvent
    :members:
    :inherited-members:

.. autoclass:: TimeSignatureEvent
    :members:
    :inherited-members:

.. autoclass:: KeySignatureEvent
    :members:
    :inherited-members:

.. autoclass:: StartEvent
    :members:
    :inherited-members:

.. autoclass:: ContinueEvent
    :members:
    :inherited-members:

.. autoclass:: StopEvent
    :members:
    :inherited-members:

.. autoclass:: SetQueuePositionTickEvent
    :members:
    :inherited-members:

.. autoclass:: SetQueuePositionTimeEvent
    :members:
    :inherited-members:

.. autoclass:: SetQueueTempoEvent
    :members:
    :inherited-members:

.. autoclass:: ClockEvent
    :members:
    :inherited-members:

.. autoclass:: TickEvent
    :members:
    :inherited-members:

.. autoclass:: QueueSkewEvent
    :members:
    :inherited-members:

.. autoclass:: SyncPositionChangedEvent
    :members:
    :inherited-members:

.. autoclass:: TuneRequestEvent
    :members:
    :inherited-members:

.. autoclass:: ResetEvent
    :members:
    :inherited-members:

.. autoclass:: ActiveSensingEvent
    :members:
    :inherited-members:

.. autoclass:: EchoEvent
    :members:
    :inherited-members:

.. autoclass:: OSSEvent
    :members:
    :inherited-members:

.. autoclass:: ClientStartEvent
    :members:
    :inherited-members:

.. autoclass:: ClientExitEvent
    :members:
    :inherited-members:

.. autoclass:: ClientChangeEvent
    :members:
    :inherited-members:

.. autoclass:: PortStartEvent
    :members:
    :inherited-members:

.. autoclass:: PortExitEvent
    :members:
    :inherited-members:

.. autoclass:: PortChangeEvent
    :members:
    :inherited-members:

.. autoclass:: PortSubscribedEvent
    :members:
    :inherited-members:

.. autoclass:: PortUnsubscribedEvent
    :members:
    :inherited-members:

.. autoclass:: SysExEvent
    :members:
    :inherited-members:

.. autoclass:: BounceEvent
    :members:
    :inherited-members:

.. autoclass:: SystemEvent
    :members:
    :inherited-members:

.. autoclass:: ResultEvent
    :members:
    :inherited-members:

.. autoclass:: UserVar0Event
    :members:
    :inherited-members:

.. autoclass:: UserVar1Event
    :members:
    :inherited-members:

.. autoclass:: UserVar2Event
    :members:
    :inherited-members:

.. autoclass:: UserVar3Event
    :members:
    :inherited-members:

.. autoclass:: MidiBytesEvent
   :members:
   :inherited-members:
